__all__ = ('BlackListPoint', 'BlackListObjectPoint')

from expressmoney.api import *
from expressmoney.api.point import DestroyPointMixin

SERVICE = 'loans'
APP = 'black_list'


class BlackListCreateContract(Contract):
    comment = serializers.CharField(max_length=128, allow_blank=True)


class BlackListReadContract(Contract):
    created = serializers.DateTimeField()
    user_id = serializers.IntegerField(min_value=1)
    comment = serializers.CharField(max_length=128, allow_blank=True)


class BlackListID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'black_list'


class BlackListPoint(ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = BlackListID()
    _read_contract = BlackListReadContract
    _create_contract = BlackListCreateContract


class BlackListObjectPoint(DestroyPointMixin, ContractObjectPoint):
    _point_id = BlackListID()



__all__ = ('IndicatorPoint', 'IndicatorFillingTaskPoint')

from expressmoney.api import *

SERVICE = 'credit-helper'
APP = 'indicators'


class IndicatorFillingTaskCreateContract(Contract):
    pass


class IndicatorDescriptionReadContract(Contract):
    name = serializers.CharField(max_length=128)
    label = serializers.CharField(max_length=128)
    description = serializers.CharField(max_length=1024)


class IndicatorReadContract(Contract):
    BAD = 'BAD'
    GOOD = 'GOOD'
    RATE_CHOICES = (
        (BAD, BAD),
        (GOOD, GOOD),
    )
    created = serializers.DateTimeField()
    description = IndicatorDescriptionReadContract()
    value = serializers.IntegerField(min_value=0)
    rate = serializers.ChoiceField(choices=RATE_CHOICES)
    recommendation = serializers.CharField(max_length=1024)


class IndicatorFillingTaskID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'indicator_filling_task'


class IndicatorID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'indicator'


class IndicatorFillingTaskPoint(CreatePointMixin, ContractPoint):
    _point_id = IndicatorFillingTaskID()
    _create_contract = IndicatorFillingTaskCreateContract


class IndicatorPoint(ListPointMixin, ContractPoint):
    _point_id = IndicatorID()
    _read_contract = IndicatorReadContract
    _sort_by = 'created'



__all__ = ('FaqPoint', 'GlossaryPoint')

from expressmoney.api import *

SERVICE = 'partners'
APP = 'support'


class FaqReadContract(Contract):
    priority = serializers.IntegerField(min_value=0)
    title = serializers.CharField(max_length=128)
    body = serializers.CharField(max_length=2048)


class GlossaryReadContract(FaqReadContract):
    pass


class FaqID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'faq'


class GlossaryID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'glossary'


class FaqPoint(ListPointMixin, ContractPoint):
    _point_id = FaqID()
    _read_contract = FaqReadContract
    _sort_by = 'priority'


class GlossaryPoint(ListPointMixin, ContractPoint):
    _point_id = GlossaryID()
    _read_contract = GlossaryReadContract
    _sort_by = 'priority'



__all__ = ('LogPoint',)

from expressmoney.api import *

SERVICE = 'auth'


class LogCreateContract(Contract):
    url = serializers.URLField()
    ip = serializers.IPAddressField()
    fingerprint = serializers.CharField(max_length=64, allow_null=True)
    ga = serializers.CharField(max_length=64, allow_null=True)
    is_set_find = serializers.BooleanField(default=False)


class LogID(ID):
    _service = SERVICE
    _app = 'users'
    _view_set = 'log'


class LogPoint(CreatePointMixin, ContractPoint):
    _point_id = LogID()
    _create_contract = LogCreateContract



__all__ = ('LoanPoint', 'LoanObjectPoint', 'PaymentPoint', 'EarlyPaymentPoint')

from djmoney.contrib.django_rest_framework import MoneyField
from expressmoney.api import *

SERVICE = 'il'


class LoanCreateContract(Contract):
    id = serializers.IntegerField(min_value=1)
    created = serializers.DateTimeField()
    order = serializers.IntegerField(min_value=1)
    bank_card_id = serializers.IntegerField(min_value=1)
    sign = serializers.IntegerField()


class LoanReadContract(Contract):
    ISSUING = 'ISSUING'
    OPEN = 'OPEN'  # Customer received money
    OVERDUE = 'OVERDUE'
    STOP_INTERESTS = 'STOP_INTERESTS'
    CLOSED = 'CLOSED'
    CANCELED = 'CANCELED'
    STATUS_CHOICES = {
        (ISSUING, ISSUING),
        (OPEN, OPEN),
        (OVERDUE, OVERDUE),
        (STOP_INTERESTS, STOP_INTERESTS),
        (CLOSED, CLOSED),
        (CANCELED, CANCELED),
    }
    id = serializers.IntegerField(min_value=1)
    created = serializers.DateTimeField()
    updated = serializers.DateTimeField()
    order = serializers.IntegerField(min_value=1)
    status = serializers.ChoiceField(choices=STATUS_CHOICES)
    bank_card_id = serializers.IntegerField(min_value=1)
    sign = serializers.IntegerField()
    interests_limit = serializers.DecimalField(max_digits=3, decimal_places=2)
    body_issue = MoneyField(max_digits=7, decimal_places=0)
    body_paid = MoneyField(max_digits=7, decimal_places=0)
    body_balance = MoneyField(max_digits=7, decimal_places=0)
    body_debt = MoneyField(max_digits=7, decimal_places=0)
    interests_charges = MoneyField(max_digits=7, decimal_places=0)
    interests_paid = MoneyField(max_digits=7, decimal_places=0)
    interests_balance = MoneyField(max_digits=7, decimal_places=0)


class PaymentCreateContract(Contract):
    loan = serializers.IntegerField(min_value=1)
    bank_card_id = serializers.IntegerField(min_value=1)


class EarlyPaymentCreateContract(Contract):
    loan = serializers.IntegerField(min_value=1)
    bank_card_id = serializers.IntegerField(min_value=1)


class LoanID(ID):
    _service = SERVICE
    _app = 'loans'
    _view_set = 'loan'


class PaymentID(ID):
    _service = SERVICE
    _app = 'loans'
    _view_set = 'payment'


class EarlyPaymentID(ID):
    _service = SERVICE
    _app = 'loans'
    _view_set = 'early_payment'


class LoanPoint(ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = LoanID()
    _read_contract = LoanReadContract
    _create_contract = LoanCreateContract


class LoanObjectPoint(RetrievePointMixin, ContractObjectPoint):
    _point_id = LoanID()
    _read_contract = LoanReadContract


class PaymentPoint(CreatePointMixin, ContractPoint):
    _point_id = PaymentID()
    _create_contract = PaymentCreateContract


class EarlyPaymentPoint(CreatePointMixin, ContractPoint):
    _point_id = EarlyPaymentID()
    _create_contract = EarlyPaymentCreateContract




__all__ = ('SamplePoint',)

from expressmoney.api import *


SERVICE = 'scoring'
APP = 'loans_ru'


class SampleReadContract(Contract):
    id = serializers.IntegerField(min_value=1)
    created = serializers.DateTimeField()
    updated = serializers.DateTimeField()
    user_id = serializers.IntegerField(min_value=1)
    # Expressmoney features
    loan_total = serializers.IntegerField()
    loan_first = serializers.IntegerField()
    loan_last = serializers.IntegerField()
    loan_between = serializers.IntegerField()
    loan_interests_sum = serializers.IntegerField()
    loan_interests_mean = serializers.IntegerField()
    loan_body_sum = serializers.IntegerField()
    loan_body_mean = serializers.IntegerField()
    # NBKI features
    total_accounts_mfo_new = serializers.IntegerField()
    total_accounts_mfo_old = serializers.IntegerField()
    total_accounts_bank_new = serializers.IntegerField()
    total_accounts_bank_old = serializers.IntegerField()
    total_accounts_other_new = serializers.IntegerField()
    total_accounts_other_old = serializers.IntegerField()
    total_accounts_active_balance_current_balance_more_0_mfo_new = serializers.IntegerField()
    total_accounts_active_balance_current_balance_more_0_mfo_old = serializers.IntegerField()
    total_accounts_active_balance_current_balance_more_0_bank_new = serializers.IntegerField()
    total_accounts_active_balance_current_balance_more_0_bank_old = serializers.IntegerField()
    total_accounts_active_balance_current_balance_more_0_other_new = serializers.IntegerField()
    total_accounts_active_balance_current_balance_more_0_other_old = serializers.IntegerField()
    total_accounts_active_balance_current_balance_0_mfo_new = serializers.IntegerField()
    total_accounts_active_balance_current_balance_0_mfo_old = serializers.IntegerField()
    total_accounts_active_balance_current_balance_0_bank_new = serializers.IntegerField()
    total_accounts_active_balance_current_balance_0_bank_old = serializers.IntegerField()
    total_accounts_active_balance_current_balance_0_other_new = serializers.IntegerField()
    total_accounts_active_balance_current_balance_0_other_old = serializers.IntegerField()
    total_accounts_negative_rating_mfo_new = serializers.IntegerField()
    total_accounts_negative_rating_mfo_old = serializers.IntegerField()
    total_accounts_negative_rating_bank_new = serializers.IntegerField()
    total_accounts_negative_rating_bank_old = serializers.IntegerField()
    total_accounts_negative_rating_other_new = serializers.IntegerField()
    total_accounts_negative_rating_other_old = serializers.IntegerField()
    total_accounts_positive_rating_mfo_new = serializers.IntegerField()
    total_accounts_positive_rating_mfo_old = serializers.IntegerField()
    total_accounts_positive_rating_bank_new = serializers.IntegerField()
    total_accounts_positive_rating_bank_old = serializers.IntegerField()
    total_accounts_positive_rating_other_new = serializers.IntegerField()
    total_accounts_positive_rating_other_old = serializers.IntegerField()
    total_accounts_past_due_current_balance_more_0_mfo_new = serializers.IntegerField()
    total_accounts_past_due_current_balance_more_0_mfo_old = serializers.IntegerField()
    total_accounts_past_due_current_balance_more_0_bank_new = serializers.IntegerField()
    total_accounts_past_due_current_balance_more_0_bank_old = serializers.IntegerField()
    total_accounts_past_due_current_balance_more_0_other_new = serializers.IntegerField()
    total_accounts_past_due_current_balance_more_0_other_old = serializers.IntegerField()
    total_accounts_past_due_current_balance_0_mfo_new = serializers.IntegerField()
    total_accounts_past_due_current_balance_0_mfo_old = serializers.IntegerField()
    total_accounts_past_due_current_balance_0_bank_new = serializers.IntegerField()
    total_accounts_past_due_current_balance_0_bank_old = serializers.IntegerField()
    total_accounts_past_due_current_balance_0_other_new = serializers.IntegerField()
    total_accounts_past_due_current_balance_0_other_old = serializers.IntegerField()
    total_accounts_closed_mfo_new = serializers.IntegerField()
    total_accounts_closed_mfo_old = serializers.IntegerField()
    total_accounts_closed_bank_new = serializers.IntegerField()
    total_accounts_closed_bank_old = serializers.IntegerField()
    total_accounts_closed_other_new = serializers.IntegerField()
    total_accounts_closed_other_old = serializers.IntegerField()
    date_last_account_mfo_new = serializers.IntegerField()
    date_last_account_mfo_old = serializers.IntegerField()
    date_last_account_bank_new = serializers.IntegerField()
    date_last_account_bank_old = serializers.IntegerField()
    date_last_account_other_new = serializers.IntegerField()
    date_last_account_other_old = serializers.IntegerField()
    date_first_account_mfo_new = serializers.IntegerField()
    date_first_account_mfo_old = serializers.IntegerField()
    date_first_account_bank_new = serializers.IntegerField()
    date_first_account_bank_old = serializers.IntegerField()
    date_first_account_other_new = serializers.IntegerField()
    date_first_account_other_old = serializers.IntegerField()
    total_amount_credit_limit_mfo_new = serializers.IntegerField()
    total_amount_credit_limit_mfo_old = serializers.IntegerField()
    total_amount_credit_limit_bank_new = serializers.IntegerField()
    total_amount_credit_limit_bank_old = serializers.IntegerField()
    total_amount_credit_limit_other_new = serializers.IntegerField()
    total_amount_credit_limit_other_old = serializers.IntegerField()
    total_amount_current_balance_mfo_new = serializers.IntegerField()
    total_amount_current_balance_mfo_old = serializers.IntegerField()
    total_amount_current_balance_bank_new = serializers.IntegerField()
    total_amount_current_balance_bank_old = serializers.IntegerField()
    total_amount_current_balance_other_new = serializers.IntegerField()
    total_amount_current_balance_other_old = serializers.IntegerField()
    total_amount_past_due_balance_mfo_new = serializers.IntegerField()
    total_amount_past_due_balance_mfo_old = serializers.IntegerField()
    total_amount_past_due_balance_bank_new = serializers.IntegerField()
    total_amount_past_due_balance_bank_old = serializers.IntegerField()
    total_amount_past_due_balance_other_new = serializers.IntegerField()
    total_amount_past_due_balance_other_old = serializers.IntegerField()
    total_amount_past_due_balance_active_mfo_new = serializers.IntegerField()
    total_amount_past_due_balance_active_mfo_old = serializers.IntegerField()
    total_amount_past_due_balance_active_bank_new = serializers.IntegerField()
    total_amount_past_due_balance_active_bank_old = serializers.IntegerField()
    total_amount_past_due_balance_active_other_new = serializers.IntegerField()
    total_amount_past_due_balance_active_other_old = serializers.IntegerField()
    total_amount_outstanding_balance_mfo_new = serializers.IntegerField()
    total_amount_outstanding_balance_mfo_old = serializers.IntegerField()
    total_amount_outstanding_balance_bank_new = serializers.IntegerField()
    total_amount_outstanding_balance_bank_old = serializers.IntegerField()
    total_amount_outstanding_balance_other_new = serializers.IntegerField()
    total_amount_outstanding_balance_other_old = serializers.IntegerField()
    total_amount_scheduled_monthly_pay_mfo_new = serializers.IntegerField()
    total_amount_scheduled_monthly_pay_mfo_old = serializers.IntegerField()
    total_amount_scheduled_monthly_pay_bank_new = serializers.IntegerField()
    total_amount_scheduled_monthly_pay_bank_old = serializers.IntegerField()
    total_amount_scheduled_monthly_pay_other_new = serializers.IntegerField()
    total_amount_scheduled_monthly_pay_other_old = serializers.IntegerField()
    total_num_days_30_mfo_new = serializers.IntegerField()
    total_num_days_30_mfo_old = serializers.IntegerField()
    total_num_days_30_bank_new = serializers.IntegerField()
    total_num_days_30_bank_old = serializers.IntegerField()
    total_num_days_30_other_new = serializers.IntegerField()
    total_num_days_30_other_old = serializers.IntegerField()
    total_num_days_60_mfo_new = serializers.IntegerField()
    total_num_days_60_mfo_old = serializers.IntegerField()
    total_num_days_60_bank_new = serializers.IntegerField()
    total_num_days_60_bank_old = serializers.IntegerField()
    total_num_days_60_other_new = serializers.IntegerField()
    total_num_days_60_other_old = serializers.IntegerField()
    total_num_days_90_mfo_new = serializers.IntegerField()
    total_num_days_90_mfo_old = serializers.IntegerField()
    total_num_days_90_bank_new = serializers.IntegerField()
    total_num_days_90_bank_old = serializers.IntegerField()
    total_num_days_90_other_new = serializers.IntegerField()
    total_num_days_90_other_old = serializers.IntegerField()
    total_pay_late_days_1_mfo_new = serializers.IntegerField()
    total_pay_late_days_1_mfo_old = serializers.IntegerField()
    total_pay_late_days_1_bank_new = serializers.IntegerField()
    total_pay_late_days_1_bank_old = serializers.IntegerField()
    total_pay_late_days_1_other_new = serializers.IntegerField()
    total_pay_late_days_1_other_old = serializers.IntegerField()
    total_pay_late_more_days_30_mfo_new = serializers.IntegerField()
    total_pay_late_more_days_30_mfo_old = serializers.IntegerField()
    total_pay_late_more_days_30_bank_new = serializers.IntegerField()
    total_pay_late_more_days_30_bank_old = serializers.IntegerField()
    total_pay_late_more_days_30_other_new = serializers.IntegerField()
    total_pay_late_more_days_30_other_old = serializers.IntegerField()
    total_pay_by_agreement_mfo_new = serializers.IntegerField()
    total_pay_by_agreement_mfo_old = serializers.IntegerField()
    total_pay_by_agreement_bank_new = serializers.IntegerField()
    total_pay_by_agreement_bank_old = serializers.IntegerField()
    total_pay_by_agreement_other_new = serializers.IntegerField()
    total_pay_by_agreement_other_old = serializers.IntegerField()
    average_time_obtaining_loan_mfo_new = serializers.IntegerField()
    average_time_obtaining_loan_mfo_old = serializers.IntegerField()
    average_time_obtaining_loan_bank_new = serializers.IntegerField()
    average_time_obtaining_loan_bank_old = serializers.IntegerField()
    average_time_obtaining_loan_other_new = serializers.IntegerField()
    average_time_obtaining_loan_other_old = serializers.IntegerField()
    total_inquiries_mfo = serializers.IntegerField()
    total_recent_inquiries_days_30_mfo = serializers.IntegerField()
    total_recent_inquiries_days_365_mfo = serializers.IntegerField()


class SampleID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'sample'


class SamplePoint(ListPointMixin, ContractPoint):
    _point_id = SampleID()
    _read_contract = SampleReadContract



__all__ = ('LinkPoint', 'NewDevicePoint')

from expressmoney.api import *


SERVICE = 'profiles'
APP = 'antifraud'


class LinkCreateContract(Contract):
    pass


class LinkReadContract(Contract):
    created = serializers.DateTimeField()
    full_name = serializers.IntegerField()
    full_name_black_list = serializers.IntegerField()
    full_name_overdue = serializers.IntegerField()
    document = serializers.IntegerField()
    document_black_list = serializers.IntegerField()
    document_overdue = serializers.IntegerField()
    address = serializers.IntegerField()
    address_black_list = serializers.IntegerField()
    address_overdue = serializers.IntegerField()
    ip = serializers.IntegerField()
    ip_black_list = serializers.IntegerField()
    ip_overdue = serializers.IntegerField()
    fingerprint = serializers.IntegerField()
    fingerprint_black_list = serializers.IntegerField()
    fingerprint_overdue = serializers.IntegerField()
    ga = serializers.IntegerField()
    ga_black_list = serializers.IntegerField()
    ga_overdue = serializers.IntegerField()
    bank_card = serializers.IntegerField()
    bank_card_black_list = serializers.IntegerField()
    bank_card_overdue = serializers.IntegerField()
    ip_fingerprint = serializers.IntegerField()
    ip_fingerprint_black_list = serializers.IntegerField()
    ip_fingerprint_overdue = serializers.IntegerField()


class NewDeviceCreateContract(Contract):
    pass


class NewDeviceResponseContract(Contract):
    is_find = serializers.BooleanField()


class LinkResponseContract(LinkReadContract):
    pass


class LinkID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'link'


class NewDeviceID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'new_device'


class LinkPoint(ResponseMixin, ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = LinkID()
    _create_contract = LinkCreateContract
    _read_contract = LinkReadContract
    _response_contract = LinkResponseContract


class NewDevicePoint(ResponseMixin, CreatePointMixin, ContractPoint):
    _point_id = NewDeviceID()
    _create_contract = NewDeviceCreateContract
    _response_contract = NewDeviceResponseContract



__all__ = ('LandingPoint',)

from expressmoney.api import *

SERVICE = 'content'
APP = 'landings'


class LandingTitleReadContract(Contract):
    text = serializers.CharField(max_length=64)


class LandingBodyReadContract(Contract):
    text = serializers.CharField(max_length=512)


class LandingFeatureReadContract(Contract):
    title = serializers.CharField(max_length=64)
    body = serializers.CharField(max_length=512)


class LandingFeaturesSetReadContract(Contract):
    name = serializers.CharField(max_length=32)
    feature_1 = LandingFeatureReadContract(allow_null=True)
    feature_2 = LandingFeatureReadContract(allow_null=True)
    feature_3 = LandingFeatureReadContract(allow_null=True)
    feature_4 = LandingFeatureReadContract(allow_null=True)
    feature_5 = LandingFeatureReadContract(allow_null=True)


class LandingReadContract(Contract):
    name = serializers.CharField(max_length=32)
    action = serializers.CharField(max_length=32)
    title = LandingTitleReadContract()
    body = LandingBodyReadContract()
    features_set = LandingFeaturesSetReadContract()


class LandingID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'landing'


class LandingPoint(ListPointMixin, ContractPoint):
    _point_id = LandingID()
    _read_contract = LandingReadContract
    _sort_by = 'name'



__all__ = ('BlackListPoint',)

from expressmoney.api import *

SERVICE = 'profiles'
APP = 'black_list'


class BlackListCreateContract(Contract):
    cause = serializers.IntegerField()
    comment = serializers.CharField(max_length=128, allow_blank=True)


class BlackListReadContract(BlackListCreateContract):
    pass


class BlackListID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'black_list'


class BlackListPoint(ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = BlackListID()
    _read_contract = BlackListReadContract
    _create_contract = BlackListCreateContract



__all__ = ('PartnerPayoutPoint', 'PartnerRevenuePoint', 'PartnerBalancePoint', 'ChargebackPoint')

from expressmoney.api import *

SERVICE = 'partners'
APP = 'accounting'


class PartnerPayoutCreateContract(Contract):
    amount = serializers.DecimalField(max_digits=16, decimal_places=0)
    bank_card_id = serializers.IntegerField(min_value=1)


class PartnerPayoutReadContract(Contract):
    created = serializers.DateTimeField()
    partner = serializers.IntegerField(min_value=1)
    amount = serializers.DecimalField(max_digits=16, decimal_places=0)
    balance = serializers.DecimalField(max_digits=16, decimal_places=0)


class PartnerRevenueReadContract(PartnerPayoutReadContract):
    pass


class PartnerBalanceReadContract(PartnerPayoutReadContract):
    pass


class ChargebackCreateContract(Contract):
    amount = serializers.DecimalField(max_digits=16, decimal_places=0)
    bank_card_id = serializers.IntegerField(min_value=1)


class PartnerPayoutID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'partner_payout'


class PartnerRevenueID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'partner_revenue'


class PartnerBalanceID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'partner_balance'


class ChargebackID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'chargeback'


class PartnerPayoutPoint(ListPointMixin, CreatePointMixin, ContractPoint):
    _point_id = PartnerPayoutID()
    _create_contract = PartnerPayoutCreateContract
    _read_contract = PartnerPayoutReadContract
    _sort_by = 'created'


class PartnerRevenuePoint(ListPointMixin, ContractPoint):
    _point_id = PartnerRevenueID()
    _read_contract = PartnerRevenueReadContract
    _sort_by = 'created'


class PartnerBalancePoint(ListPointMixin, ContractPoint):
    _point_id = PartnerBalanceID()
    _read_contract = PartnerBalanceReadContract
    _sort_by = 'created'


class ChargebackPoint(CreatePointMixin, ContractPoint):
    _point_id = ChargebackID()
    _create_contract = ChargebackCreateContract



__all__ = ('PartnerPoint', 'PartnerObjectPoint')

from django.core.validators import RegexValidator
from expressmoney.api import *

SERVICE = 'partners'
APP = 'partners'


class PartnerCreateContract(Contract):
    pass


class PartnerUpdateContract(Contract):
    code = serializers.CharField(max_length=8,
                                 validators=(RegexValidator(regex='^[A-Z0-9]*$',
                                                            message='invalid_format',
                                                            code='invalid_format'
                                                            ),),
                                 )


class PartnerReadContract(PartnerUpdateContract):
    created = serializers.DateTimeField()
    balance = serializers.DecimalField(max_digits=16, decimal_places=1)


class PartnerID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'partner'


class PartnerPoint(CreatePointMixin, ContractPoint):
    _point_id = PartnerID()
    _create_contract = PartnerCreateContract


class PartnerObjectPoint(RetrievePointMixin, UpdatePointMixin, ContractObjectPoint):
    _point_id = PartnerID()
    _read_contract = PartnerReadContract
    _update_contract = PartnerUpdateContract



__all__ = ('WhiteListPoint', 'WhiteListObjectPoint')

from expressmoney.api import *
from expressmoney.api.point import DestroyPointMixin

SERVICE = 'loans'
APP = 'antifraud'


class WhiteListCreateContract(Contract):
    comment = serializers.CharField(max_length=128, allow_blank=True)


class WhiteListReadContract(WhiteListCreateContract):
    created = serializers.DateTimeField()


class WhiteListID(ID):
    _service = SERVICE
    _app = APP
    _view_set = 'white_list'


class WhiteListPoint(CreatePointMixin, ContractPoint):
    _point_id = WhiteListID()
    _read_contract = WhiteListReadContract
    _create_contract = WhiteListCreateContract


class WhiteListObjectPoint(DestroyPointMixin, ContractObjectPoint):
    _point_id = WhiteListID()



"""
py setup.py sdist
twine upload dist/expressmoney-points-1.20.2.tar.gz
"""
import setuptools

setuptools.setup(
    name='expressmoney-points',
    packages=setuptools.find_packages(),
    version='1.20.2',
    description='Service points',
    author='Development team',
    author_email='dev@expressmoney.com',
    install_requires=('expressmoney>=11.0.7', 'django-money'),
    python_requires='>=3.7',
)



__all__ = ('SmsPoint', 'SmsToReferralPoint')

from expressmoney.api import *

SERVICE = 'notifications'


class SmsCreateContract(Contract):
    message = serializers.CharField(min_length=1, max_length=60)


class SmsToReferralContract(Contract):
    message = serializers.CharField(max_length=130)
    phonenumber = serializers.CharField(max_length=20)


class SmsID(ID):
    _service = SERVICE
    _app = 'sms'
    _view_set = 'sms'


class SmsToReferralID(ID):
    _service = SERVICE
    _app = 'sms'
    _view_set = 'sms_to_referral'


class SmsPoint(CreatePointMixin, ContractPoint):
    _point_id = SmsID()
    _create_contract = SmsCreateContract


class SmsToReferralPoint(CreatePointMixin, ContractPoint):
    _point_id = SmsToReferralID()
    _create_contract = SmsToReferralContract
